// This code controls the backlight pin (GPIO 13) via the variable ulp_lcd_mode
//n(ulp_lcd_mode==0 -> OFF, ulp_lcd_mode==1 -> ON, ulp_lcd_mode>1 BLINK) 

#include "soc/soc_ulp.h"     // for WRITE_RTC_REG
#include "soc/rtc_io_reg.h"  // for RTC_GPIO_*


  .bss

  .global lcd_mode
    
lcd_mode:  .long 0

  .global time_counter
    
time_counter:  .long 0


  .global timer_calibrate
    
timer_calibrate:  .long 0

  .text

  .global entry                // ulp start address used by main core program

  .set gpio_13, 14              // gpio pin 13 is rtc pin 14

   move r3, timer_calibrate
   

entry:
  // might be needed for some pads, but surely not #2
  // WRITE_RTC_REG(RTC_IO_TOUCH_PAD2_REG, RTC_IO_TOUCH_PAD2_TO_GPIO_S, 1, 1)

  // use digital function, not rtc function
  WRITE_RTC_REG(RTC_IO_TOUCH_PAD2_REG, RTC_IO_TOUCH_PAD2_MUX_SEL_S, 1, 1)

  // gpio_13 shall be output, not input
  WRITE_RTC_REG(RTC_GPIO_OUT_REG, RTC_GPIO_OUT_DATA_S + gpio_13, 1, 1)

on:

  move r1, time_counter
  ld r0, r1, 0
  add   r0, r0, 1
  st r0, r1, 0 

  move r1, lcd_mode    // Get adress of x
  ld r0, r1, 0  // Read ulp_lcd_mode in r0, if 0 then jump to off
  jumpr onskip, 0, EQ
  WRITE_RTC_REG(RTC_GPIO_ENABLE_W1TS_REG, RTC_GPIO_ENABLE_W1TS_S + gpio_13, 1, 1)

onskip:

  ld r1, r3, 0              // fill r1 with ulp_calibrate
  //move  r1, 540           // wait in ms
  move  r2, off           // return address
  
  jump  delay             // call subroutine

off:
  move r1, lcd_mode    // Get adress of x
  ld r0, r1, 0  // Read ulp_lcd_mode in r0, if 1 then jump to on
  jumpr offskip, 1, EQ
  WRITE_RTC_REG(RTC_GPIO_ENABLE_W1TC_REG, RTC_GPIO_ENABLE_W1TC_S + gpio_13, 1, 1)
  
offskip:
  //move  r1, 540           // wait in ms
  ld r1, r3, 0            // fill r1 with ulp_calibrate
  move  r2, on            // return address
  jump  delay             // call subroutine

delay:
  wait  800              // wait 800 clock ticks at 8MHz -> 100us, compensate for ASM instruction execution time
 
  sub   r1, r1, 1         // decrement ms count
  jump  r2, eq            // if ms count is zero then return to caller
  jump  delay             // else continue to wait
